#
# spec file for package python3-pytest
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pytest
Version:        2.7.2
Release:        3.20
Summary:        Simple powerful testing with Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://pytest.org
Source:         http://pypi.python.org/packages/source/p/pytest/pytest-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  unzip
# Test requirements:
%if 0%{?suse_version} <= 1310
# mock is built-in for python 3.4
BuildRequires:  python3-mock
%endif
BuildRequires:  python3-PyYAML
BuildRequires:  python3-py >= 1.4.22
BuildRequires:  python3-setuptools
Requires:       python3-py >= 1.4.22
Requires:       python3-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
pytest helps you write better programs. It is a a mature full-featured,
cross-project Python testing tool. It provides:

* auto-discovery of test modules and functions,
* detailed info on failing assert statements (no need to remember 
  self.assert* names),
* modular fixtures for managing small or parametrized long-lived test resources.
* multi-paradigm support: you can use py.test to run test suites based on 
  unittest (or trial), nose,
* single-source compatibility to Python2.5 all the way up to Python3.3, 
  PyPy-1.9 and Jython-2.5.1, and
* many external plugins.


%prep
%setup -q -n pytest-%{version}
#TODO(saschpe): Fix failing tests:
# rm testing/test_junitxml.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm %{buildroot}%{_bindir}/py.test 
ln -s %{_bindir}/py.test-%{py3_ver} %{buildroot}%{_bindir}/py.test

%check
python3 setup.py test 

%pre
# Since /usr/bin/py.test became ghosted to be used
# with update-alternatives, we have to get rid of the old binary resulting from the
# non-update-alternativies-ified package:
[ -h %{_bindir}/py.test ] || rm -f %{_bindir}/py.test

%post
update-alternatives \
    --install %{_bindir}/py.test py.test %{_bindir}/py.test-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove py.test %{_bindir}/py.test-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%ghost %{_bindir}/py.test
%ghost %{_sysconfdir}/alternatives/py.test
%{_bindir}/py.test-%{py3_ver}
%{python3_sitelib}/*

%changelog
* Mon Aug 31 2015 badshah400@gmail.com
- Add python3 as BuildRequires; this fixes build failures
  otherwise seen on openSUSE:42 due to missing xml module.
* Wed Jul  8 2015 toddrme2178@gmail.com
- Split documentation into separate package to avoid build loop
* Tue Jun 30 2015 arun@gmx.de
- update to version 2.7.2:
  * fix issue767: pytest.raises value attribute does not contain the
    exception instance on Python 2.6. Thanks Eric Siegerman for
    providing the test case and Bruno Oliveira for PR.
  * Automatically create directory for junitxml and results
    log. Thanks Aron Curzon.
  * fix issue713: JUnit XML reports for doctest failures. Thanks
    Punyashloka Biswal.
  * fix issue735: assertion failures on debug versions of Python 3.4+
    Thanks Benjamin Peterson.
  * fix issue114: skipif marker reports to internal skipping plugin;
    Thanks Floris Bruynooghe for reporting and Bruno Oliveira for the
    PR.
  * fix issue748: unittest.SkipTest reports to internal pytest
    unittest plugin. Thanks Thomas De Schampheleire for reporting and
    Bruno Oliveira for the PR.
  * fix issue718: failed to create representation of sets containing
    unsortable elements in python 2. Thanks Edison Gustavo Muenz
  * fix issue756, fix issue752 (and similar issues): depend on
    py-1.4.29 which has a refined algorithm for traceback generation.
* Wed May 20 2015 toddrme2178@gmail.com
- Update to version 2.7.1:
  * fix issue731: do not get confused by the braces which may be
    present and unbalanced in an object's repr while collapsing
    False explanations.  Thanks Carl Meyer for the report and test
    case.
  * fix issue553: properly handling inspect.getsourcelines
    failures in FixtureLookupError which would lead to to an
    internal error, obfuscating the original problem. Thanks
    talljosh for initial diagnose/patch and Bruno Oliveira for
    final patch.
  * fix issue660: properly report scope-mismatch-access errors
    independently from ordering of fixture arguments.  Also
    avoid the pytest internal traceback which does not provide
    information to the user. Thanks Holger Krekel.
  * streamlined and documented release process.  Also all
    versions (in setup.py and documentation generation) are now
    read from _pytest/__init__.py. Thanks Holger Krekel.
  * fixed docs to remove the notion that yield-fixtures are
    experimental. They are here to stay :)  Thanks Bruno Oliveira.
  * Support building wheels by using environment markers for the
    requirements.  Thanks Ionel Maries Cristian.
  * fixed regression to 2.6.4 which surfaced e.g. in lost stdout
    capture printing when tests raised SystemExit. Thanks
    Holger Krekel.
  * reintroduced _pytest fixture of the pytester plugin which
    is used at least by pytest-xdist.
* Sat Mar 28 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.7.0:
  * fix issue435: make reload() work when assert rewriting is
    active. Thanks Daniel Hahler.
  * fix issue616: conftest.py files and their contained fixutres are
    now properly considered for visibility, independently from the
    exact current working directory and test arguments that are
    used. Many thanks to Eric Siegerman and his PR235 which contains
    systematic tests for conftest visibility and now passes. This
    change also introduces the concept of a rootdir which is printed
    as a new pytest header and documented in the pytest customize web
    page.
  * change reporting of "diverted" tests, i.e. tests that are
    collected in one file but actually come from another (e.g. when
    tests in a test class come from a base class in a different
    file). We now show the nodeid and indicate via a postfix the other
    file.
  * add ability to set command line options by environment variable
    PYTEST_ADDOPTS.
  * added documentation on the new pytest-dev teams on bitbucket and
    github. See https://pytest.org/latest/contributing.html . Thanks
    to Anatoly for pushing and initial work on this.
  * fix issue650: new option --docttest-ignore-import-errors which
    will turn import errors in doctests into skips. Thanks Charles
    Cloud for the complete PR.
  * fix issue655: work around different ways that cause python2/3 to
    leak sys.exc_info into fixtures/tests causing failures in 3rd
    party code
  * fix issue615: assertion re-writing did not correctly escape %%
    signs when formatting boolean operations, which tripped over
    mixing booleans with modulo operators. Thanks to Tom Viner for the
    report, triaging and fix.
  * implement issue351: add ability to specify parametrize ids as a
    callable to generate custom test ids. Thanks Brianna Laugher for
    the idea and implementation.
  * introduce and document new hookwrapper mechanism useful for
    plugins which want to wrap the execution of certain hooks for
    their purposes. This supersedes the undocumented __multicall__
    protocol which pytest itself and some external plugins use. Note
    that pytest-2.8 is scheduled to drop supporting the old
    __multicall__ and only support the hookwrapper protocol.
  * majorly speed up invocation of plugin hooks
  * use hookwrapper mechanism in builtin pytest plugins.
  * add a doctest ini option for doctest flags, thanks Holger Peters.
  * add note to docs that if you want to mark a parameter and the
    parameter is a callable, you also need to pass in a reason to
    disambiguate it from the "decorator" case. Thanks Tom Viner.
  * "python_classes" and "python_functions" options now support
    glob-patterns * for test discovery, as discussed in
    issue600. Thanks Ldiary Translations.
  * allow to override parametrized fixtures with non-parametrized ones
    and vice versa (bubenkoff).
  * fix issue463: raise specific error for ‘parameterize’ misspelling
    (pfctdayelise).
  * On failure, the sys.last_value, sys.last_type and
    sys.last_traceback are set, so that a user can inspect the error
    via postmortem debugging (almarklein).
* Wed Dec 31 2014 arun@gmx.de
- update to version 2.6.4:
  * Improve assertion failure reporting on iterables, by using ndiff and
    pprint.
  * removed outdated japanese docs from source tree.
  * docs for "pytest_addhooks" hook.  Thanks Bruno Oliveira.
  * updated plugin index docs.  Thanks Bruno Oliveira.
  * fix issue557: with "-k" we only allow the old style "-" for negation
    at the beginning of strings and even that is deprecated.  Use "not" instead.
    This should allow to pick parametrized tests where "-" appeared in the parameter.
  * fix issue604: Escape %% character in the assertion message.
  * fix issue620: add explanation in the --genscript target about what
    the binary blob means. Thanks Dinu Gherman.
  * fix issue614: fixed pastebin support.
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Sun Oct  5 2014 toms@opensuse.org
- Update to 2.6.3
  - No longer show line numbers in the –verbose output, the output
    is now purely the nodeid. The line number is still shown in
    failure reports. Thanks Floris Bruynooghe.
  - fix issue437 where assertion rewriting could cause pytest-xdist
    slaves to collect different tests.
    Thanks Bruno Oliveira.
  - fix issue555: add “errors” attribute to capture-streams to
    satisfy some distutils and possibly other code accessing sys.stdout.errors.
  - fix issue547 capsys/capfd also work when output capturing (“-s”)
    is disabled.
  - address issue170: allow pytest.mark.xfail(...) to specify expected
    exceptions via an optional “raises=EXC” argument where EXC can be
    a single exception or a tuple of exception classes.
    Thanks David Mohr for the complete PR.
  - fix integration of pytest with unittest.mock.patch decorator when
    it uses the “new” argument.
    Thanks Nicolas Delaby for test and PR.
  - fix issue with detecting conftest files if the arguments contain
    ”::” node id specifications (copy pasted from “-v” output)
  - fix issue544 by only removing “@NUM” at the end of ”::” separated
    parts and if the part has an ”.py” extension  don’t use py.std
    import helper, rather import things directly.
    Thanks Bruno Oliveira.
  See for other releases: http://pytest.org/latest/changelog.html
* Wed Jul 30 2014 toddrme2178@gmail.com
- Update to 2.6.0
  - Cache exceptions from fixtures according to their scope (issue 467).
  - fix issue537: Avoid importing old assertion reinterpretation code by default.
  - fix issue364: shorten and enhance tracebacks representation by default.
    The new "--tb=auto" option (default) will only display long tracebacks
    for the first and last entry.  You can get the old behaviour of printing
    all entries as long entries with "--tb=long".  Also short entries by
    default are now printed very similarly to "--tb=native" ones.
  - fix issue514: teach assertion reinterpretation about private class attributes
  - change -v output to include full node IDs of tests.  Users can copy
    a node ID from a test run, including line number, and use it as a
    positional argument in order to run only a single test.
  - fix issue 475: fail early and comprehensible if calling
    pytest.raises with wrong exception type.
  - fix issue516: tell in getting-started about current dependencies.
  - cleanup setup.py a bit and specify supported versions. Thanks Jurko
    Gospodnetic for the PR.
  - change XPASS colour to yellow rather then red when tests are run
    with -v.
  - fix issue473: work around mock putting an unbound method into a class
    dict when double-patching.
  - fix issue498: if a fixture finalizer fails, make sure that
    the fixture is still invalidated.
  - fix issue453: the result of the pytest_assertrepr_compare hook now gets
    it's newlines escaped so that format_exception does not blow up.
  - internal new warning system: pytest will now produce warnings when
    it detects oddities in your test collection or execution.
    Warnings are ultimately sent to a new pytest_logwarning hook which is
    currently only implemented by the terminal plugin which displays
    warnings in the summary line and shows more details when -rw (report on
    warnings) is specified.
  - change skips into warnings for test classes with an __init__ and
    callables in test modules which look like a test but are not functions.
  - fix issue436: improved finding of initial conftest files from command
    line arguments by using the result of parse_known_args rather than
    the previous flaky heuristics.  Thanks Marc Abramowitz for tests
    and initial fixing approaches in this area.
  - fix issue #479: properly handle nose/unittest(2) SkipTest exceptions
    during collection/loading of test modules.  Thanks to Marc Schlaich
    for the complete PR.
  - fix issue490: include pytest_load_initial_conftests in documentation
    and improve docstring.
  - fix issue472: clarify that ``pytest.config.getvalue()`` cannot work
    if it's triggered ahead of command line parsing.
  - merge PR123: improved integration with mock.patch decorator on tests.
  - fix issue412: messing with stdout/stderr FD-level streams is now
    captured without crashes.
  - fix issue483: trial/py33 works now properly.  Thanks Daniel Grana for PR.
  - improve example for pytest integration with "python setup.py test"
    which now has a generic "-a" or "--pytest-args" option where you
    can pass additional options as a quoted string.  Thanks Trevor Bekolay.
  - simplified internal capturing mechanism and made it more robust
    against tests or setups changing FD1/FD2, also better integrated
    now with pytest.pdb() in single tests.
  - improvements to pytest's own test-suite leakage detection, courtesy of PRs
    from Marc Abramowitz
  - fix issue492: avoid leak in test_writeorg.  Thanks Marc Abramowitz.
  - fix issue493: don't run tests in doc directory with ``python setup.py test``
    (use tox -e doctesting for that)
  - fix issue486: better reporting and handling of early conftest loading failures
  - some cleanup and simplification of internal conftest handling.
  - work a bit harder to break reference cycles when catching exceptions.
    Thanks Jurko Gospodnetic.
  - fix issue443: fix skip examples to use proper comparison.  Thanks Alex
    Groenholm.
  - support nose-style ``__test__`` attribute on modules, classes and
    functions, including unittest-style Classes.  If set to False, the
    test will not be collected.
  - fix issue512: show "<notset>" for arguments which might not be set
    in monkeypatch plugin.  Improves output in documentation.
* Wed Jul 23 2014 bwiedemann@suse.com
- Add Requires: python3-setuptools (bnc#886855)
* Fri Jul 18 2014 toddrme2178@gmail.com
- Don't install mock on python 3.4, it is no longer needed as it
  is now built-in.
* Thu Jul  3 2014 speilicke@suse.com
- Update requirements
- Don't invoke 2to3 anymore, code works without
* Thu Apr 17 2014 toddrme2178@gmail.com
- Update to 2.5.2:
  - fix issue409 -- better interoperate with cx_freeze by not
    trying to import from collections.abc which causes problems
    for py27/cx_freeze.  Thanks Wolfgang L. for reporting and tracking it down.
  - fixed docs and code to use "pytest" instead of "py.test" almost everywhere.
    Thanks Jurko Gospodnetic for the complete PR.
  - fix issue425: mention at end of "py.test -h" that --markers
    and --fixtures work according to specified test path (or current dir)
  - fix issue413: exceptions with unicode attributes are now printed
    correctly also on python2 and with pytest-xdist runs. (the fix
    requires py-1.4.20)
  - copy, cleanup and integrate py.io capture
    from pylib 1.4.20.dev2 (rev 13d9af95547e)
  - address issue416: clarify docs as to conftest.py loading semantics
  - fix issue429: comparing byte strings with non-ascii chars in assert
    expressions now work better.  Thanks Floris Bruynooghe.
  - make capfd/capsys.capture private, its unused and shouldnt be exposed
* Fri Jan  3 2014 mvyskocil@suse.com
- Update to 2.5.1:
  + merge new documentation styling PR from Tobias Bieniek.
  + fix issue403: allow parametrize of multiple same-name functions within
    a collection node.
  + Allow parameterized fixtures to specify the ID of the parameters by
    adding an ids argument to pytest.fixture() and pytest.yield_fixture().
  + fix issue404 by always using the binary xml escape in the junitxml
    plugin.
  + fix issue407: fix addoption docstring to point to argparse instead of
    optparse.
  * 2.5.0:
  + dropped python2.5 from automated release testing of pytest itself
    which means it's probably going to break soon
  + simplified and fixed implementation for calling finalizers when
    parametrized fixtures or function arguments are involved.  finalization
    is now performed lazily at setup time instead of in the "teardown phase".
  + PR90: add --color=yes|no|auto option to force terminal coloring
    mode ("auto" is default).
  + fix issue319 - correctly show unicode in assertion errors. Also means
    we depend on py>=1.4.19 now.
  + fix issue396 - correctly sort and finalize class-scoped parametrized
    tests independently from number of methods on the class.
  + refix issue323 in a better way -- parametrization should now never
    cause Runtime Recursion errors because the underlying algorithm
    for re-ordering tests per-scope/per-fixture is not recursive
    anymore
  + fix issue290 - there is preliminary support now for parametrizing
    with repeated same values (sometimes useful to to test if calling
    a second time works as with the first time).
  + close issue240 - document precisely how pytest module importing
    works, discuss the two common test directory layouts, and how it
    interacts with PEP420-namespace packages.
  + fix issue246 fix finalizer order to be LIFO on independent fixtures
    depending on a parametrized higher-than-function scoped fixture.
    (was quite some effort so please bear with the complexity of
    this sentence :)
  + fix issue244 by implementing special index for parameters to only use
    indices for paramentrized test ids
  + fix issue287 by running all finalizers but saving the exception
    from the first failing finalizer and re-raising it so teardown will
    still have failed.  We reraise the first failing exception because
    it might be the cause for other finalizers to fail.
  + fix ordering when mock.patch or other standard decorator-wrappings
    are used with test methods.  This fixues issue346 and should
    help with random "xdist" collection failures.  Thanks to
    Ronny Pfannschmidt and Donald Stufft for helping to isolate it.
  + and many more, see CHANGELOG for details
- require python3-py at least 1.4.19
- mark /etc/alternatives/py.test as ghost file
* Thu Aug  1 2013 speilicke@suse.com
- Build-require 2to3 for 12.2
* Tue Jun 18 2013 speilicke@suse.com
- Use update-alternatives
* Mon Jun 17 2013 speilicke@suse.com
- Update to version 2.3.5:
  + never consider a fixture function for test function collection
  + allow re-running of test items / helps to fix pytest-reruntests plugin
    and also help to keep less fixture/resource references alive
  + put captured stdout/stderr into junitxml output even for passing tests
    (thanks Adam Goucher)
  + Issue 265 - integrate nose setup/teardown with setupstate
    so it doesnt try to teardown if it did not setup
  + issue 271 - dont write junitxml on slave nodes
  + Issue 274 - dont try to show full doctest example
    when doctest does not know the example location
  + issue 280 - disable assertion rewriting on buggy CPython 2.6.0
  + inject "getfixture()" helper to retrieve fixtures from doctests,
    thanks Andreas Zeidler
  + issue 259 - when assertion rewriting, be consistent with the default
    source encoding of ASCII on Python 2
  + issue 251 - report a skip instead of ignoring classes with init
  + issue250 unicode/str mixes in parametrization names and values now works
  + issue257, assertion-triggered compilation of source ending in a
    comment line doesn't blow up in python2.5 (fixed through py>=1.4.13.dev6)
  + fix --genscript option to generate standalone scripts that also
    work with python3.3 (importer ordering)
  + issue171 - in assertion rewriting, show the repr of some
    global variables
  + fix option help for "-k"
  + move long description of distribution into README.rst
  + improve docstring for metafunc.parametrize()
  + fix bug where using capsys with pytest.set_trace() in a test
    function would break when looking at capsys.readouterr()
  + allow to specify prefixes starting with "_" when
    customizing python_functions test discovery. (thanks Graham Horler)
  + improve PYTEST_DEBUG tracing output by puting
    extra data on a new lines with additional indent
  + ensure OutcomeExceptions like skip/fail have initialized exception attributes
  + issue 260 - don't use nose special setup on plain unittest cases
  + fix issue134 - print the collect errors that prevent running specified test items
  + fix issue266 - accept unicode in MarkEvaluator expressions
* Thu May  2 2013 speilicke@suse.com
- Initial version
